# -*- coding: utf-8 -*-
# Generated by Django 1.10.4 on 2016-12-22 18:21
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("onfido", "0010_convert_raw_fields_to_jsonb"),
    ]

    operations = [
        migrations.AlterField(
            model_name="check",
            name="status",
            field=models.CharField(
                blank=True,
                choices=[
                    (
                        "Check",
                        (
                            ("in_progress", "In progress"),
                            ("awaiting_applicant", "Awaiting applicant"),
                            ("complete", "Complete"),
                            ("withdrawn", "Withdrawn"),
                            ("paused", "Paused"),
                            ("reopened", "Reopened"),
                        ),
                    ),
                    (
                        "Report",
                        (
                            ("awaiting_data", "Awaiting data"),
                            ("awaiting_approval", "Awaiting approval"),
                            ("complete", "Complete"),
                            ("withdrawn", "Withdrawn"),
                            ("paused", "Paused"),
                            ("cancelled", "Cancelled"),
                        ),
                    ),
                ],
                db_index=True,
                help_text="The current state of the check / report (from API).",
                max_length=20,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="report",
            name="status",
            field=models.CharField(
                blank=True,
                choices=[
                    (
                        "Check",
                        (
                            ("in_progress", "In progress"),
                            ("awaiting_applicant", "Awaiting applicant"),
                            ("complete", "Complete"),
                            ("withdrawn", "Withdrawn"),
                            ("paused", "Paused"),
                            ("reopened", "Reopened"),
                        ),
                    ),
                    (
                        "Report",
                        (
                            ("awaiting_data", "Awaiting data"),
                            ("awaiting_approval", "Awaiting approval"),
                            ("complete", "Complete"),
                            ("withdrawn", "Withdrawn"),
                            ("paused", "Paused"),
                            ("cancelled", "Cancelled"),
                        ),
                    ),
                ],
                db_index=True,
                help_text="The current state of the check / report (from API).",
                max_length=20,
                null=True,
            ),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("onfido", "0003_auto_20161023_1455"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="event",
            name="onfido_id",
        ),
        migrations.RemoveField(
            model_name="event",
            name="status_after",
        ),
        migrations.RemoveField(
            model_name="event",
            name="status_before",
        ),
        migrations.AddField(
            model_name="event",
            name="raw",
            field=models.TextField(
                default="{}",
                help_text="The raw JSON returned from the API.",
                null=True,
                blank=True,
            ),
        ),
        migrations.AddField(
            model_name="event",
            name="resource_id",
            field=models.CharField(
                default="",
                help_text="The Onfido id of the object that was updated, returned from the API.",
                max_length=40,
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="event",
            name="status",
            field=models.CharField(
                default="",
                help_text="The status of the object after the event.",
                max_length=20,
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="event",
            name="user",
            field=models.ForeignKey(
                related_name="onfido_events",
                blank=True,
                to=settings.AUTH_USER_MODEL,
                on_delete=models.CASCADE,
                help_text="The user who triggered the event.",
                null=True,
            ),
        ),
    ]



from __future__ import annotations

import logging

from django.conf import settings
from django.db import models
from django.utils.translation import gettext_lazy as _

from ..settings import scrub_applicant_data
from .base import BaseModel, BaseQuerySet

logger = logging.getLogger(__name__)


class ApplicantQuerySet(BaseQuerySet):
    """Custom Applicant queryset."""

    def create_applicant(self, user: settings.AUTH_USER_MODEL, raw: dict) -> Applicant:
        """Create a new applicant in Onfido from a user."""
        logger.debug("Creating new Onfido applicant from JSON: %s", raw)
        return Applicant(user=user).parse(raw).save()


class Applicant(BaseModel):
    """An Onfido applicant record."""

    base_href = "applicants"

    user = models.OneToOneField(
        settings.AUTH_USER_MODEL,
        on_delete=models.CASCADE,
        help_text=_("Django user that maps to this applicant."),
        related_name="onfido_applicant",
    )

    objects = ApplicantQuerySet.as_manager()

    def __str__(self) -> str:
        return str(self.user)

    def __repr__(self) -> str:
        return "<Applicant id={} user_id={}>".format(self.id, self.user.id)

    def parse(self, raw_json: dict) -> Applicant:
        """
        Parse the raw value out into other properties.

        Before parsing the data, this method will call the
        scrub_report_data function to remove sensitive data
        so that it is not saved into the local object.

        """
        super().parse(scrub_applicant_data(raw_json))
        return self



# Generated by Django 3.1.5 on 2021-01-30 16:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("onfido", "0012_add_event_received_at_timestamp"),
    ]

    operations = [
        migrations.AlterField(
            model_name="report",
            name="report_type",
            field=models.CharField(
                choices=[
                    ("document", "Document"),
                    (
                        "document_with_address_information",
                        "Document with Address Information",
                    ),
                    (
                        "document_with_driving_licence_information",
                        "Document with Driving Licence Information",
                    ),
                    ("facial_similarity_photo", "Facial Similarity (photo)"),
                    ("facial_similarity_photo_fully_auto", "Facial Similarity (auto)"),
                    ("facial_similarity_video", "Facial Similarity (video)"),
                    ("known_faces", "Known Faces"),
                    ("identity_enhanced", "Identity (enhanced)"),
                    ("watchlist_enhanced", "Watchlist (enhanced)"),
                    ("watchlist_standard", "Watchlist"),
                    ("watchlist_peps_only", "Watchlist (PEPs only)"),
                    ("watchlist_sanctions_only", "Watchlist (sanctions only)"),
                    ("proof_of_address", "Proof of Address"),
                    ("right_to_work", "Right to Work"),
                    ("identity", "x Identity report (deprecated)"),
                    ("street_level", "x Street level report (deprecated)"),
                    ("facial_similarity", "x Facial similarity report (deprecated)"),
                    ("credit", "x Credit report (deprecated)"),
                    ("criminal_history", "x Criminal history (deprecated)"),
                    ("ssn_trace", "SSN trace (deprecated)"),
                ],
                help_text="The name of the report - see https://documentation.onfido.com/#reports",
                max_length=50,
            ),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("onfido", "0008_rename_event_created_at"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="event",
            options={"ordering": ["completed_at"]},
        ),
        migrations.AddField(
            model_name="check",
            name="is_clear",
            field=models.BooleanField(
                default=None,
                null=True,
                blank=True,
                help_text="True if the check / report is 'clear' (via API or manual override).",
            ),
        ),
        migrations.AddField(
            model_name="report",
            name="is_clear",
            field=models.BooleanField(
                default=None,
                null=True,
                blank=True,
                help_text="True if the check / report is 'clear' (via API or manual override).",
            ),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-11-15 22:50
from __future__ import unicode_literals

from django.db import migrations

from ..compat import JSONField


class Migration(migrations.Migration):

    dependencies = [
        ("onfido", "0009_add_is_clear_field"),
    ]

    operations = [
        migrations.AlterField(
            model_name="applicant",
            name="raw",
            field=JSONField(
                blank=True, help_text="The raw JSON returned from the API.", null=True
            ),
        ),
        migrations.AlterField(
            model_name="check",
            name="raw",
            field=JSONField(
                blank=True, help_text="The raw JSON returned from the API.", null=True
            ),
        ),
        migrations.AlterField(
            model_name="report",
            name="raw",
            field=JSONField(
                blank=True, help_text="The raw JSON returned from the API.", null=True
            ),
        ),
        migrations.AlterField(
            model_name="event",
            name="raw",
            field=JSONField(
                blank=True, help_text="The raw JSON returned from the API.", null=True
            ),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("onfido", "0005_remove_event_user"),
    ]

    operations = [
        migrations.RenameField(
            model_name="event",
            old_name="completed_at",
            new_name="created_at",
        ),
        migrations.RenameField(
            model_name="event", old_name="resource_id", new_name="onfido_id"
        ),
    ]



from __future__ import annotations

import logging

from django.conf import settings
from django.db import models
from django.utils.translation import gettext_lazy as _

from ..settings import scrub_report_data
from .base import BaseQuerySet, BaseStatusModel
from .check import Check

logger = logging.getLogger(__name__)


class ReportQuerySet(BaseQuerySet):
    """Report model queryset."""

    def create_report(self, check: Check, raw: dict) -> Report:
        """Create a new Report from the raw JSON."""
        logger.debug("Creating new Onfido report from JSON: %s", raw)
        return Report(user=check.user, onfido_check=check).parse(raw).save()


class Report(BaseStatusModel):
    """Specific reports associated with a Check."""

    base_href = "reports"

    # v2 API report types - retained for backwards compatibility,
    # but superseded by ReportType
    REPORT_TYPE_CHOICES_DEPRECATED = [
        ("identity", "x Identity report (deprecated)"),
        # ("document", "Document report"),
        ("street_level", "x Street level report (deprecated)"),
        ("facial_similarity", "x Facial similarity report (deprecated)"),
        ("credit", "x Credit report (deprecated)"),
        ("criminal_history", "x Criminal history (deprecated)"),
        # ("right_to_work", "Right to work"),
        ("ssn_trace", "SSN trace (deprecated)"),
    ]

    class ReportType(models.TextChoices):
        # https://documentation.onfido.com/#report-names-in-api
        DOCUMENT = ("document", "Document")
        DOCUMENT_WITH_ADDRESS_INFORMATION = (
            "document_with_address_information",
            "Document with Address Information",
        )
        DOCUMENT_WITH_DRIVING_LICENCE_INFORMATION = (
            "document_with_driving_licence_information",
            "Document with Driving Licence Information",
        )
        FACIAL_SIMILARITY_PHOTO = (
            "facial_similarity_photo",
            "Facial Similarity (photo)",
        )
        FACIAL_SIMILARITY_PHOTO_FULLY_AUTO = (
            "facial_similarity_photo_fully_auto",
            "Facial Similarity (auto)",
        )
        FACIAL_SIMILARITY_VIDEO = (
            "facial_similarity_video",
            "Facial Similarity (video)",
        )
        KNOWN_FACES = ("known_faces", "Known Faces")
        IDENTITY_ENHANCED = ("identity_enhanced", "Identity (enhanced)")
        WATCHLIST_ENHANCED = ("watchlist_enhanced", "Watchlist (enhanced)")
        WATCHLIST_STANDARD = ("watchlist_standard", "Watchlist")
        WATCHLIST_PEPS_ONLY = ("watchlist_peps_only", "Watchlist (PEPs only)")
        WATCHLIST_SANCTIONS_ONLY = (
            "watchlist_sanctions_only",
            "Watchlist (sanctions only)",
        )
        PROOF_OF_ADDRESS = ("proof_of_address", "Proof of Address")
        RIGHT_TO_WORK = ("right_to_work", "Right to Work")

    user = models.ForeignKey(
        settings.AUTH_USER_MODEL,
        on_delete=models.CASCADE,
        help_text=_(
            "The Django user (denormalised from Applicant to make navigation easier)."
        ),  # noqa
        related_name="onfido_reports",
    )
    onfido_check = models.ForeignKey(
        Check,
        on_delete=models.CASCADE,
        help_text=_("Check to which this report is attached."),
        related_name="reports",
    )
    report_type = models.CharField(
        max_length=50,
        choices=ReportType.choices + REPORT_TYPE_CHOICES_DEPRECATED,
        help_text=_(
            "The name of the report - see https://documentation.onfido.com/#reports"
        ),
    )

    objects = ReportQuerySet.as_manager()

    def __str__(self) -> str:
        return "{} for {}".format(
            self.get_report_type_display().capitalize(), self.user
        )

    def __repr__(self) -> str:
        return "<Report id={} type='{}' user_id={}>".format(
            self.id, self.report_type, self.user.id
        )

    def parse(self, raw_json: dict) -> Report:
        """
        Parse the raw value out into other properties.

        Before parsing the data, this method will call the
        scrub_report_data function to remove sensitive data
        so that it is not saved into the local object.

        """
        super().parse(scrub_report_data(raw_json))
        self.report_type = self.raw["name"]
        return self



from __future__ import annotations

import logging

from django.conf import settings
from django.db import models
from django.utils.translation import gettext_lazy as _

from .applicant import Applicant
from .base import BaseQuerySet, BaseStatusModel

logger = logging.getLogger(__name__)


class CheckQuerySet(BaseQuerySet):
    """Check model manager."""

    def create_check(self, applicant: Applicant, raw: dict) -> Check:
        """Create a new Check object from the raw JSON."""
        logger.debug("Creating new Onfido check from JSON: %s", raw)
        return Check(user=applicant.user, applicant=applicant).parse(raw).save()


class Check(BaseStatusModel):
    """The state of an individual check made against an Applicant."""

    base_href = "checks"

    user = models.ForeignKey(
        settings.AUTH_USER_MODEL,
        on_delete=models.CASCADE,
        help_text=_(
            "The Django user (denormalised from Applicant to make navigation easier)."
        ),  # noqa
        related_name="onfido_checks",
    )
    applicant = models.ForeignKey(
        Applicant,
        on_delete=models.CASCADE,
        help_text=_("The applicant for whom the check is being made."),
        related_name="checks",
    )

    objects = CheckQuerySet.as_manager()

    def __str__(self) -> str:
        return f"Onfido check for {self.user}"

    def __repr__(self) -> str:
        return f"<Check id={self.id} user_id={self.user_id}>"



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("onfido", "0004_auto_20161023_1648"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="event",
            name="user",
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("onfido", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="Event",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                (
                    "resource_type",
                    models.CharField(
                        help_text="The resource_type returned from the API callback.",
                        max_length=20,
                    ),
                ),
                (
                    "onfido_id",
                    models.CharField(
                        help_text="The id returned from the Onfido API.", max_length=40
                    ),
                ),
                (
                    "action",
                    models.CharField(
                        help_text="The resource_type returned from the API callback.",
                        max_length=20,
                    ),
                ),
                (
                    "status_before",
                    models.CharField(
                        help_text="The status of the object before the event.",
                        max_length=20,
                    ),
                ),
                (
                    "status_after",
                    models.CharField(
                        help_text="The status of the object after the event.",
                        max_length=20,
                    ),
                ),
                (
                    "completed_at",
                    models.DateTimeField(
                        help_text="The completed_at timestamp returned from the API callback."
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        related_name="onfido_events",
                        to=settings.AUTH_USER_MODEL,
                        on_delete=models.CASCADE,
                        help_text="The user who triggered the event.",
                    ),
                ),
            ],
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="Applicant",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                (
                    "onfido_id",
                    models.CharField(
                        help_text="The id returned from the Onfido API.",
                        unique=True,
                        max_length=40,
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(
                        help_text="The timestamp returned from the Onfido API.",
                        null=True,
                        blank=True,
                    ),
                ),
                (
                    "raw",
                    models.TextField(
                        default="{}",
                        help_text="The raw JSON returned from the API.",
                        null=True,
                        blank=True,
                    ),
                ),
                (
                    "user",
                    models.OneToOneField(
                        related_name="onfido_applicant",
                        to=settings.AUTH_USER_MODEL,
                        on_delete=models.CASCADE,
                        help_text="Django user that maps to this applicant.",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="Check",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                (
                    "onfido_id",
                    models.CharField(
                        help_text="The id returned from the Onfido API.",
                        unique=True,
                        max_length=40,
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(
                        help_text="The timestamp returned from the Onfido API.",
                        null=True,
                        blank=True,
                    ),
                ),
                (
                    "raw",
                    models.TextField(
                        default="{}",
                        help_text="The raw JSON returned from the API.",
                        null=True,
                        blank=True,
                    ),
                ),
                (
                    "status",
                    models.CharField(
                        blank=True,
                        max_length=20,
                        null=True,
                        help_text="The current state of the check / report (from API).",
                        choices=[
                            (
                                "Check",
                                (
                                    ("in_progress", "In progress"),
                                    ("awaiting_applicant", "Awaiting applicant"),
                                    ("complete", "Complete"),
                                    ("withdrawn", "Withdrawn"),
                                    ("paused", "Paused"),
                                    ("reopened", "Reopened"),
                                ),
                            ),
                            (
                                "Report",
                                (
                                    ("awaiting_data", "Awaiting data"),
                                    ("awaiting_approval", "Awaiting approval"),
                                    ("complete", "Complete"),
                                    ("withdrawn", "Withdrawn"),
                                    ("paused", "Paused"),
                                    ("cancelled", "Cancelled"),
                                ),
                            ),
                        ],
                    ),
                ),
                (
                    "result",
                    models.CharField(
                        blank=True,
                        max_length=20,
                        null=True,
                        help_text="The final result of the check / reports (from API).",
                        choices=[
                            ("Check", (("clear", "Clear"), ("consider", "Consider"))),
                            (
                                "Report",
                                (
                                    ("clear", "Clear"),
                                    ("consider", "Consider"),
                                    ("unidentified", "Unidentified"),
                                ),
                            ),
                        ],
                    ),
                ),
                (
                    "updated_at",
                    models.DateTimeField(
                        help_text="The timestamp of the most recent status change (from API).",
                        null=True,
                        blank=True,
                    ),
                ),
                # COMMENTED OUT DELIBERATELY SO THAT THE COLUMNS REMAINS IN DATABASE
                # (
                #     "check_type",
                #     models.CharField(
                #         help_text="See https://documentation.onfido.com/#check-types",
                #         max_length=10,
                #         choices=[
                #             ("express", "Express check"),
                #             ("standard", "Standard check"),
                #         ],
                #     ),
                # ),
                (
                    "applicant",
                    models.ForeignKey(
                        related_name="checks",
                        to="onfido.Applicant",
                        on_delete=models.CASCADE,
                        help_text="The applicant for whom the check is being made.",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        related_name="onfido_checks",
                        to=settings.AUTH_USER_MODEL,
                        on_delete=models.CASCADE,
                        help_text="The Django user (denormalised from Applicant to make navigation easier).",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="Report",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                (
                    "onfido_id",
                    models.CharField(
                        help_text="The id returned from the Onfido API.",
                        unique=True,
                        max_length=40,
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(
                        help_text="The timestamp returned from the Onfido API.",
                        null=True,
                        blank=True,
                    ),
                ),
                (
                    "raw",
                    models.TextField(
                        default="{}",
                        help_text="The raw JSON returned from the API.",
                        null=True,
                        blank=True,
                    ),
                ),
                (
                    "status",
                    models.CharField(
                        blank=True,
                        max_length=20,
                        null=True,
                        help_text="The current state of the check / report (from API).",
                        choices=[
                            (
                                "Check",
                                (
                                    ("in_progress", "In progress"),
                                    ("awaiting_applicant", "Awaiting applicant"),
                                    ("complete", "Complete"),
                                    ("withdrawn", "Withdrawn"),
                                    ("paused", "Paused"),
                                    ("reopened", "Reopened"),
                                ),
                            ),
                            (
                                "Report",
                                (
                                    ("awaiting_data", "Awaiting data"),
                                    ("awaiting_approval", "Awaiting approval"),
                                    ("complete", "Complete"),
                                    ("withdrawn", "Withdrawn"),
                                    ("paused", "Paused"),
                                    ("cancelled", "Cancelled"),
                                ),
                            ),
                        ],
                    ),
                ),
                (
                    "result",
                    models.CharField(
                        blank=True,
                        max_length=20,
                        null=True,
                        help_text="The final result of the check / reports (from API).",
                        choices=[
                            ("Check", (("clear", "Clear"), ("consider", "Consider"))),
                            (
                                "Report",
                                (
                                    ("clear", "Clear"),
                                    ("consider", "Consider"),
                                    ("unidentified", "Unidentified"),
                                ),
                            ),
                        ],
                    ),
                ),
                (
                    "updated_at",
                    models.DateTimeField(
                        help_text="The timestamp of the most recent status change (from API).",
                        null=True,
                        blank=True,
                    ),
                ),
                (
                    "report_type",
                    models.CharField(
                        help_text="The name of the report - see https://documentation.onfido.com/#reports",
                        max_length=20,
                        choices=[
                            ("identity", "Identity report"),
                            ("document", "Document report"),
                            ("street_level", "Street level report"),
                            ("facial_similarity", "Facial similarity report"),
                            ("credit", "Credit report"),
                            ("criminal_history", "Criminal history"),
                            ("right_to_work", "Right to work"),
                            ("ssn_trace", "SSN trace"),
                        ],
                    ),
                ),
                (
                    "onfido_check",
                    models.ForeignKey(
                        related_name="reports",
                        to="onfido.Check",
                        on_delete=models.CASCADE,
                        help_text="Check to which this report is attached.",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        related_name="onfido_reports",
                        to=settings.AUTH_USER_MODEL,
                        on_delete=models.CASCADE,
                        help_text="The Django user (denormalised from Applicant to make navigation easier).",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("onfido", "0007_rename_onfido_id_verbose_name"),
    ]

    operations = [
        migrations.AlterField(
            model_name="event",
            name="created_at",
            field=models.DateTimeField(
                help_text="The timestamp returned from the Onfido API.",
                null=True,
                blank=True,
            ),
        ),
        migrations.RenameField(
            model_name="event",
            old_name="created_at",
            new_name="completed_at",
        ),
    ]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['onfido',
 'onfido.management',
 'onfido.management.commands',
 'onfido.migrations',
 'onfido.models']

package_data = \
{'': ['*']}

install_requires = \
['django>=2.2,<4.0', 'python-dateutil', 'requests', 'simplejson']

setup_kwargs = {
    'name': 'django-onfido',
    'version': '1.0b0',
    'description': 'Django app for integration with Onfido.',
    'long_description': '.. image:: https://travis-ci.org/yunojuno/django-onfido.svg?branch=master\n    :target: https://travis-ci.org/yunojuno/django-onfido\n\n.. image:: https://badge.fury.io/py/django-onfido.svg\n    :target: https://badge.fury.io/py/django-onfido\n\nDjango Onfido\n==============\n\nDjango app for integration with the Onfido API (v2)\n\nBackground\n----------\n\nOnfido is an online identity verification service. It provides API access to a\nrange of tests (identity, right to work, criminal history, credit report). It\nis assumed that you are only interested in this project because you are\nalready aware of what Onfido does, and so I won\'t repeat it here. If you want\nto find out more, head over to their website.\n\nIf you *are* using Onfido, and you are using Django, then this project can be\nused to manage Onfido checks against your existing Django users. It handles\nthe API interactions, as well as providing the callback webhooks required to\nsupport live status updates.\n\nInstallation\n------------\n\nThe project is available through PyPI as ``django-onfido``:\n\n.. code::\n\n    $ pip install django-onfido\n\nAnd the main package itself is just ``onfido``:\n\n.. code:: python\n\n    >>> from onfido import api, models, views, urls, admin, signals, helpers, decorators\n\nUsage\n-----\n\nThe main use case is as follows:\n\n1. Create an Onfido **Applicant** from your Django user:\n\n.. code:: python\n\n    >>> from django.contrib.auth import get_user_model\n    >>> from onfido.helpers import create_applicant\n    >>> user = get_user_model().objects.last()  # any old one will do\n    >>> applicant = create_applicant(user)\n    DEBUG Making POST request to https://api.onfido.com/v3/applicants\n    DEBUG <Response [201]>\n    DEBUG {u\'first_name\': u\'hugo\', u\'last_name\': u\'rb\', u\'middle_name\': None, ...}\n    DEBUG Creating new Onfido applicant from JSON: {u\'first_name\': u\'hugo\', u\'last_name\': u\'rb\', ...}\n    <Applicant id=a2c98eae-XXX user=\'hugo\'>\n\n2. Create your check + reports for the applicant:\n\n.. code:: python\n\n    >>> from onfido.helpers import create_check\n    >>> create_check(applicant, \'standard\', [\'identity\', \'right_to_work\'])\n    >>> assert Check.objects.count() == 1\n    >>> assert Report.objects.count() == 2\n\nThis will create the **Check** and **Report** objects on Onfido, and store them locally as Django model objects.\n\n3. Wait for callback events to update the status of reports and checks:\n\n.. code:: shell\n\n    DEBUG Received Onfido callback: {"payload":{...}}\n    DEBUG Processing \'check.completed\' action on check.bd8232c4-...\n\nNB If you are using the callback functionality, you **must** set the ``ONFIDO_WEBHOOK_TOKEN``\nproperty (see settings section below). The callback handler will force verification of the\nX-Signature request header as specified in the `webhooks documentation <https://documentation.onfido.com/#webhooks>`_.\n\nThe raw JSON returned from the API for a given entity (``Applicant``,\n``Check``, ``Report``) is stored on the model as the ``raw`` attribute, and\nthis can be parsed into the relevant model attributes. (Yes this does mean\nduplication of data.) The core pattern for interaction with the API on a per-\nobject basis is a read-only fetch / pull pattern (analagous to git operations\nof the same name). If you call the ``fetch`` method on an object, it will use\nthe ``href`` value in the raw JSON to fetch the latest data from the API and\nparse it, but without saving the changes. If you want to update the object,\nuse the ``pull`` method instead.\n\nThe ``Report`` object is a special case, where the raw data from the API often\ncontains sensitive information that you may not wish to store locally\n(passport numbers, Visa information, personal data). In order to get around\nthis, there is a ``scrub_report_data`` function that will remove certain\nattributes of the raw data before it is parsed. By default this will remove\nthe ``breakdown`` and ``properties`` elements.\n\n.. code:: python\n\n    >>> check = Check.objects.last()\n    >>> check.raw\n    {\n        "id": "c26f22d5-4903-401f-8a48-7b0211d03c1f",\n        "created_at": "2016-10-15T19:05:50Z",\n        "status": "awaiting_applicant",\n        "type": "standard",\n        "result": "clear",\n        "href": "applicants/123/checks/456"\n    }\n    >>> check.fetch()  # fetch and parse the latest raw data\n    >>> check.pull()  # calls fetch and then saves the object\n\nThere is a management command ``onfido_sync`` which can be used to ``pull`` all the objects\nin a queryset. It takes a single positional arg - \'applicant\', check\' or \'report\', and has two\noptions - ``--filter`` and ``--exclude`` - both of which take multiple space-separated\nargs which can be used to manage the queryset that is used.\n\nExamples:\n\n.. code:: bash\n\n    $ ./manage.py onfido_sync check\n    $ ./manage.py onfido_sync report\n    $ ./manage.py onfido_sync check --filter complete\n    $ ./manage.py onfido_sync check --exclude complete\n\nSettings\n--------\n\nThe following settings can be specified as environment settings or within the Django settings.\n\n* ``ONFIDO_API_KEY``: your API key, found under **setting** in your Onfido account.\n* ``ONFIDO_WEBHOOK_TOKEN``: (optional) the Onfido webhook callback token - required if using webhooks.\n\nThe following settings can be specified in the Django settings:\n\n* ``ONFIDO_LOG_EVENTS``: (optional) if True then callback events from the API will also be recorded as ``Event`` objects. Defaults to False.\n* ``ONFIDO_REPORT_SCRUBBER``: (optional) a function that is used to scrub sensitive data from ``Report`` objects. The default implementation will remove **breakdown** and **properties**.\n\nTests\n-----\n\nThe project has pretty good test coverage (>90%) and the tests themselves run through ``tox``.\n\n.. code::\n\n    $ pip install tox\n    $ tox\n\nIf you want to run the tests manually, make sure you install the requirements, and Django.\n\n.. code::\n\n    $ pip install -r requirements.txt\n    $ pip install django==1.8  # your version goes here\n    $ python manage.py test onfido.tests\n\nIf you are hacking on the project, please keep coverage up.\n\nContributing\n------------\n\nStandard GH rules apply: clone the repo to your own account, create a branch,\nmake sure you update the tests, and submit a pull request.\n\nStatus\n------\n\nThis project is very early in its development. We are using it at YunoJuno,\nbut \'caveat emptor\'. It currently only supports \'standard\' checks, and has\nvery patchy support for the full API. It does what we need it to do right now,\nand we will extend it as we evolve. If you need or want additional features,\nget involved :-).\n',
    'author': 'YunoJuno',
    'author_email': 'code@yunojuno.com',
    'maintainer': 'YunoJuno',
    'maintainer_email': 'code@yunojuno.com',
    'url': 'https://github.com/yunojuno/django-onfido',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



from __future__ import annotations

from argparse import ArgumentParser
from typing import Any

from django.core.management.base import BaseCommand

from ...models import Applicant, Check, Report


class Command(BaseCommand):

    help = "Pull all Check / Report objects."

    def add_arguments(self, parser: ArgumentParser) -> None:
        parser.add_argument(
            "model",
            choices=["applicant", "check", "report"],
            help="Type of model to sync",
        )
        parser.add_argument(
            "--filter", nargs="+", help="Status field values to filter on"
        )
        parser.add_argument(
            "--exclude", nargs="+", help="Status field values to exclude"
        )

    def handle(self, *args: Any, **options: Any) -> None:

        if options["model"] == "check":
            model = Check
        elif options["model"] == "report":
            model = Report
        elif options["model"] == "applicant":
            model = Applicant

        filters = options["filter"]
        excludes = options["exclude"]

        objs = model.objects.all()
        objs = objs.filter(status__in=filters) if filters else objs
        objs = objs.exclude(status__in=excludes) if excludes else objs
        objs.pull()



from __future__ import annotations

import hashlib
import hmac
import logging
from functools import wraps
from typing import Any, Callable

from django.core.exceptions import ImproperlyConfigured
from django.http import HttpRequest, HttpResponse, HttpResponseForbidden

from .settings import TEST_MODE, WEBHOOK_TOKEN

logger = logging.getLogger(__name__)


def _hmac(token: bytes, text: bytes) -> str:
    """
    Calculate SHA1 HMAC digest from request body and token.

    Args:
        token: bytes, the webhook token from Onfido API settings.
        text: string, the text to hash.

    Return the SHA1 HMAC as a string.

    """
    auth_code = hmac.new(token, text, hashlib.sha1).hexdigest()
    logger.debug("Onfido callback request HMAC: %s", auth_code)
    return auth_code


def _match(token: bytes, request: HttpRequest) -> bool:
    """
    Calculate signature and return True if it matches header.

    Args:
        token: string, the webhook_token.
        request: an HttpRequest object from which the body content and
            X-Signature header will be extracted and matched.

    Returns True if there is a match.

    """
    try:
        signature = request.META["HTTP_X_SIGNATURE"]
        logger.debug("Onfido callback X-Signature: %s", signature)
        logger.debug("Onfido callback request body: %s", request.body)
        return _hmac(token, request.body) == signature
    except KeyError:
        logger.warning(
            "Onfido callback missing X-Signature - this may be an unauthorised request."
        )
        return False
    except Exception:
        logger.exception("Error attempting to decode Onfido signature.")
        return False


def verify_signature() -> Callable:
    """
    View function decorator used to verify Onfido webhook signatures.

    This function uses the WEBHOOK_TOKEN specified in settings to calculate
    the HMAC. If it doesn't exist, then this decorator will immediately fail
    hard with an ImproperlyConfigured exception.

    If TEST_MODE is on (ONFIDO_TEST_MODE setting) then the verification will
    be ignored.

    See: https://documentation.onfido.com/#webhooks

        Each webhook URL is associated with a secret token. This is
        visible in the response.token field when registering a webhook.

        Events sent to your application will be signed using this token:
        verifying the request signature on your server prevents attackers
        from imitating valid webhooks. The HMAC digest signature, generated
        using SHA-1, will be stored in a X-Signature header.

        When you receive an event, you should compute a hash using your
        secret token, and ensure that the X-Signature sent by Onfido
        matches that hash.

    If the HMAC signatures don't match, return a 403

    """

    def decorator(func: Callable) -> Callable:
        @wraps(func)
        def _wrapped_func(
            request: HttpRequest, *args: Any, **kwargs: Any
        ) -> HttpResponse:
            if TEST_MODE:
                logger.debug(
                    "Ignoring Onfido callback verification (ONFIDO_TEST_MODE enabled)"
                )
                return func(request, *args, **kwargs)
            if not WEBHOOK_TOKEN:
                raise ImproperlyConfigured("Missing ONFIDO_WEBHOOK_TOKEN")
            if _match(WEBHOOK_TOKEN, request):
                return func(request, *args, **kwargs)
            else:
                # logging as a warning means it'll likely appear in logs,
                # but it's by design - if people are sending invalid requests
                # we need to know.
                logger.warning("Onfido callback request verification failed.")
                return HttpResponseForbidden("Invalid X-Signature")

        return _wrapped_func

    return decorator
